Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2041)

Unified Diff: chrome/browser/ntp_snippets/download_suggestions_provider.h

Issue 2683553003: [NTP::Downloads] Consider recently visited offline pages not outdated. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/ntp_snippets/download_suggestions_provider.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ntp_snippets/download_suggestions_provider.h
diff --git a/chrome/browser/ntp_snippets/download_suggestions_provider.h b/chrome/browser/ntp_snippets/download_suggestions_provider.h
index 9cac825d2e4a652f04f5e5fe81fd32d855c7c055..951be129e046cc26daf53d081af94cca4778880c 100644
--- a/chrome/browser/ntp_snippets/download_suggestions_provider.h
+++ b/chrome/browser/ntp_snippets/download_suggestions_provider.h
@@ -141,9 +141,10 @@ class DownloadSuggestionsProvider
ntp_snippets::ContentSuggestion ConvertDownloadItem(
const content::DownloadItem& download_item) const;
- // Returns true if a download published time is considered too old for the
- // download to be shown.
- bool IsDownloadOutdated(const base::Time& published_time);
+ // Returns true if a download published and last visited times are considered
+ // too old for the download to be shown.
+ bool IsDownloadOutdated(const base::Time& published_time,
+ const base::Time& last_visited_time);
// Adds |item| to the internal asset download cache if all of the following
// holds:
« no previous file with comments | « no previous file | chrome/browser/ntp_snippets/download_suggestions_provider.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698